@@ -99,7 +99,12 @@ class AmocrmApiLoader(AmocrmApiLoaderBase, ABC):
 
                 url = url_base.format(limit=self.batch_api, page=cur_page)
 
-                objects = self.oath_client.get_response_objects(url, params)
+                try:
+                    objects = self.oath_client.get_response_objects(url, params)
+                except:
+                    import time
+                    time.sleep(3)
+                    objects = self.oath_client.get_response_objects(url, params)
 
                 self.logger.info(objects.url)
                 if objects.status_code != 200:
